Package error
package error
-
ClassDescriptionThis class represents the body of an HTTP Request which resulted in error on the Globalping service.This class represents an exception that occurs on Globalping service when a forbidden resource/operation is performed.Represents an API error encountered when interacting with the Globalping service.This class represents an internal server error occurred on Globalping service.This class represents an exception that occurs on Globalping service when a resource/operation is not found.This class represents error on payload and it extends
Exception.This class represents an exception that occurs on Globalping service when no suitable probes are found.This class represents an error getting results and it extendsException.This class represents an exception that occurs on Globalping service when too many requests are sent triggering rate limiting behaviour.This class represents an exception that occurs on Globalping service when a resource/operation needs an authorization and none provided.This class represents an exception that occurs on Globalping service when a resource/operation request is made with incorrect payload.