Package model

Class CreateMeasurementResponse

java.lang.Object
model.GlobalpingResponse
model.CreateMeasurementResponse

public class CreateMeasurementResponse extends GlobalpingResponse
Represents the response for a measurement request, containing the ID of the newly created measurement and the number of probes used.

This class extends GlobalpingResponse and provides additional information.

  • Constructor Details

    • CreateMeasurementResponse

      public CreateMeasurementResponse()