Package model

Class MeasurementLocationOption

java.lang.Object
model.MeasurementLocationOption

public class MeasurementLocationOption extends Object
This class represents various measurement location options, except limit the others can be present one at a time.

For example: in a single MeasurementLocationOption you will not find continent and region both values given.

Use static with****** methods to construct measurement location options.

Use setLimit(Integer) to change the limit.