Package model
Class MeasurementTarget
java.lang.Object
model.MeasurementTarget
This class represents target of the measurement.
A publicly reachable measurement target. Typically a hostname, an IPv4 address, or IPv6 address, depending on the measurement type.
Note: Support for IPv6 targets is currently considered experimental.
-
Constructor Summary
ConstructorsConstructorDescriptionMeasurementTarget(TargetType ttype, String text) Constructor to safely creates instance of the class, pre-emptively checks if target is valid. -
Method Summary
-
Constructor Details
-
MeasurementTarget
Constructor to safely creates instance of the class, pre-emptively checks if target is valid.- Parameters:
ttype-TargetTypetype of the target Hostname, IPv4, IPv6text-Stringtarget value- Throws:
PayloadException- when type does not match the given value
-