Package model

Class PingOptions

java.lang.Object
model.PingOptions
All Implemented Interfaces:
MeasurementOption

public class PingOptions extends Object implements MeasurementOption
Represents the Ping-specific options used when performing a Ping type of measurement. This class implements the MeasurementOption interface with parameters required for the Ping queries.