Uses of Class
model.MeasurementLocationOption
Packages that use MeasurementLocationOption
-
Uses of MeasurementLocationOption in model
Methods in model that return MeasurementLocationOptionModifier and TypeMethodDescriptionstatic MeasurementLocationOptionConstructsMeasurementLocationOptionwith only asn and default limit.static MeasurementLocationOptionConstructsMeasurementLocationOptionwith only city and default limit.static MeasurementLocationOptionMeasurementLocationOption.withContinent(ContinentCode continent) ConstructsMeasurementLocationOptionwith only continent and default limit.static MeasurementLocationOptionMeasurementLocationOption.withCountry(String country) ConstructsMeasurementLocationOptionwith only country and default limit.static MeasurementLocationOptionConstructsMeasurementLocationOptionwith only magic and default limit.static MeasurementLocationOptionMeasurementLocationOption.withNetwork(String network) ConstructsMeasurementLocationOptionwith only network and default limit.static MeasurementLocationOptionMeasurementLocationOption.withRegion(RegionName region) ConstructsMeasurementLocationOptionwith only region and default limit.static MeasurementLocationOptionConstructsMeasurementLocationOptionwith only state and default limit.static MeasurementLocationOptionConstructsMeasurementLocationOptionwith only tags and default limit.Constructor parameters in model with type arguments of type MeasurementLocationOptionModifierConstructorDescriptionMeasurementLocations(List<MeasurementLocationOption> locationOptions) Constructor to create an instance with just list ofMeasurementLocationOption.