Uses of Interface
model.MeasurementOption
Packages that use MeasurementOption
-
Uses of MeasurementOption in model
Classes in model that implement MeasurementOptionModifier and TypeClassDescriptionclassRepresents the DNS-specific options used when performing a DNS type of measurement.classRepresents the measurement options used when performing a Http type of measurement.classRepresents the Mtr-specific options used when performing a Mtr type of measurement.classRepresents the Ping-specific options used when performing a Ping type of measurement.classRepresents the Traceroute-specific options used when performing a Traceroute type of measurement.Methods in model with parameters of type MeasurementOptionModifier and TypeMethodDescriptionMeasurementRequest.MeasurementRequestBuilder.withMeasurementOptions(MeasurementOption measurementOptions) Chain method for setting value of measurementOptions.