Package model.enums

Enum ContinentCode

java.lang.Object
java.lang.Enum<ContinentCode>
model.enums.ContinentCode
All Implemented Interfaces:
Serializable, Comparable<ContinentCode>, java.lang.constant.Constable

public enum ContinentCode extends Enum<ContinentCode>
Enum represent two-letter continent code which Globalping service supports.
  • Enum Constant Details

  • Method Details

    • values

      public static ContinentCode[] values()
      Returns an array containing the constants of this enum type, in the order they are declared.
      Returns:
      an array containing the constants of this enum type, in the order they are declared
    • valueOf

      public static ContinentCode valueOf(String name)
      Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum type has no constant with the specified name
      NullPointerException - if the argument is null