Uses of Enum
model.enums.ContinentCode
Packages that use ContinentCode
-
Uses of ContinentCode in model
Methods in model with parameters of type ContinentCodeModifier and TypeMethodDescriptionstatic MeasurementLocationOptionMeasurementLocationOption.withContinent(ContinentCode continent) ConstructsMeasurementLocationOptionwith only continent and default limit. -
Uses of ContinentCode in model.enums
Methods in model.enums that return ContinentCodeModifier and TypeMethodDescriptionstatic ContinentCodeReturns the enum constant of this type with the specified name.static ContinentCode[]ContinentCode.values()Returns an array containing the constants of this enum type, in the order they are declared.