Package model
package model
-
ClassDescriptionThis class represents a base class for all the measurement results. it contains status and rawOutput which is common for all the measurements.Represents the response for a measurement request, containing the ID of the newly created measurement and the number of probes used.Represents the DNS-specific options used when performing a DNS type of measurement.This class represents a builder for Dns Options.This class is an alias for BaseTestResult representing a result of a failed request.This class represents Dns measurement test results and holds a generic value of it.This class represents Http measurement test results and it extends
BaseTestResult.This class represents Mtr measurement test results and it extendsBaseTestResult.This class represents Ping measurement test results and it extendsBaseTestResult.This class represents a DNS measurement test withtracedisabled.This class represents a DNS measurement test withtraceenabled.This class represents Traceroute measurement test results and it extendsBaseTestResult.This class represents a request object used by HttpClient to communicate with Globalping service.This class represents a generic response received from a Globalping service.Represents the measurement options used when performing a Http type of measurement.This class represents a builder for Http Options.Details about the HTTP request times in the response of measurement request of typehttp.This class is an alias for BaseTestResult representing a result of an in-progress request.This class represents an object containing credits information (only for authenticated requests).This class represents an object containing measurements rate limits.This class represents limits which are part of the measurement response.This class represents Http request properties within the measurement of typehttp.This class represents various measurement location options, except limit the others can be present one at a time.This class represents locations of the measurements.Represents a measurement option used in API requests, providing methods to convert the option into JSON format.This class represents request payload for the measurement.This class represent a builder for Measurement Request.This class represents a measurement response from Globalping service.This class represents target of the measurement.This class represents DNS Answers returned from the DNS measurement tests.This class represents DNS hop in DNS measurement tests.This class extends stats of measurement results, it contains additional fields along with the extendedMeasurementTestStats.This class represents a general hop in the measurements of types like traceroute, mtr, etc.This class extends hops in the measurement results, it contains additional fields along with the extendedMeasurementTestHop.Summary (Round-trip time)rttand packet loss statistics.Represents the Mtr-specific options used when performing a Mtr type of measurement.This class represents a builder for Mtr Options.This class is an alias for BaseTestResult representing a result of an offline request.Represents the Ping-specific options used when performing a Ping type of measurement.This class represents a builder for Dns Options.This class represents a Globalping Probe and it's properties.This class represents Location property of a Globalping Probe.This class represents a wrapper around a list of probes.This class represents an object containing rate limits information.This class represents an object containing rate limit details.This class represents a TLS certificate.Information about the certificate issuer.This class represents information about the certificate subject.Represents the Traceroute-specific options used when performing a Traceroute type of measurement.This class represents a builder for Traceroute Options.