Uses of Package
model
Packages that use model
-
Classes in model used by Unnamed PackageClassDescriptionThis class represents a request object used by HttpClient to communicate with Globalping service.This class represents a generic response received from a Globalping service.
-
ClassDescriptionThis class represents a base class for all the measurement results. it contains status and rawOutput which is common for all the measurements.Represents the DNS-specific options used when performing a DNS type of measurement.This class represents a builder for Dns Options.This class represents Http measurement test results and it extends
BaseTestResult.This class represents Mtr measurement test results and it extendsBaseTestResult.This class represents Ping measurement test results and it extendsBaseTestResult.This class represents Traceroute measurement test results and it extendsBaseTestResult.This class represents a generic response received from a Globalping service.Represents the measurement options used when performing a Http type of measurement.This class represents a builder for Http Options.This class represents Http request properties within the measurement of typehttp.This class represents various measurement location options, except limit the others can be present one at a time.This class represents locations of the measurements.Represents a measurement option used in API requests, providing methods to convert the option into JSON format.This class represents request payload for the measurement.This class represent a builder for Measurement Request.This class represents target of the measurement.This class represents a general hop in the measurements of types like traceroute, mtr, etc.Summary (Round-trip time)rttand packet loss statistics.Represents the Mtr-specific options used when performing a Mtr type of measurement.This class represents a builder for Mtr Options.Represents the Ping-specific options used when performing a Ping type of measurement.This class represents a builder for Dns Options.This class represents a Globalping Probe and it's properties.Represents the Traceroute-specific options used when performing a Traceroute type of measurement.This class represents a builder for Traceroute Options.