Package model
Class MeasurementLocationOption
java.lang.Object
model.MeasurementLocationOption
This class represents various measurement location options, except limit the others can be
present one at a time.
For example: in a single MeasurementLocationOption you will not find continent and region both values given.
Use static with****** methods to construct measurement location options.
Use setLimit(Integer) to change the limit.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionvoidSets the limit.static MeasurementLocationOptionConstructsMeasurementLocationOptionwith only asn and default limit.static MeasurementLocationOptionConstructsMeasurementLocationOptionwith only city and default limit.static MeasurementLocationOptionwithContinent(ContinentCode continent) ConstructsMeasurementLocationOptionwith only continent and default limit.static MeasurementLocationOptionwithCountry(String country) ConstructsMeasurementLocationOptionwith only country and default limit.static MeasurementLocationOptionConstructsMeasurementLocationOptionwith only magic and default limit.static MeasurementLocationOptionwithNetwork(String network) ConstructsMeasurementLocationOptionwith only network and default limit.static MeasurementLocationOptionwithRegion(RegionName region) ConstructsMeasurementLocationOptionwith only region and default limit.static MeasurementLocationOptionConstructsMeasurementLocationOptionwith only state and default limit.static MeasurementLocationOptionConstructsMeasurementLocationOptionwith only tags and default limit.
-
Constructor Details
-
MeasurementLocationOption
public MeasurementLocationOption()
-
-
Method Details
-
withContinent
ConstructsMeasurementLocationOptionwith only continent and default limit.- Parameters:
continent- validContinentCode- Returns:
MeasurementLocationOption
-
withRegion
ConstructsMeasurementLocationOptionwith only region and default limit.- Parameters:
region- validRegionName- Returns:
MeasurementLocationOption
-
withCountry
ConstructsMeasurementLocationOptionwith only country and default limit.- Parameters:
country-country- Returns:
MeasurementLocationOption
-
withState
ConstructsMeasurementLocationOptionwith only state and default limit.- Parameters:
state-state- Returns:
MeasurementLocationOption
-
withCity
ConstructsMeasurementLocationOptionwith only city and default limit.- Parameters:
city-city- Returns:
MeasurementLocationOption
-
withAsn
ConstructsMeasurementLocationOptionwith only asn and default limit.- Parameters:
asn-asn- Returns:
MeasurementLocationOption
-
withNetwork
ConstructsMeasurementLocationOptionwith only network and default limit.- Parameters:
network-network- Returns:
MeasurementLocationOption
-
withTags
ConstructsMeasurementLocationOptionwith only tags and default limit.- Parameters:
tags-tags- Returns:
MeasurementLocationOption
-
withMagic
ConstructsMeasurementLocationOptionwith only magic and default limit.- Parameters:
magic-magic- Returns:
MeasurementLocationOption
-
setLimit
Sets the limit.- Parameters:
limit- limit to change to must be within the rage of 1 to 200.- Throws:
PayloadException- if the given limit is off the range
-